Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/tinylora_simpletest.py
    :caption: examples/tinylora_simpletest.py
    :linenos:

Using TinyLora with a Sensor
----------------------------

Using TinyLoRa with a Si7021 Sensor

.. literalinclude:: ../examples/tinylora_simpletest_si7021.py
    :caption: examples/tinylora_simpletest_si7021.py
    :linenos:

Using a single Channel
----------------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/tinylora_simpletest_single_channel.py
    :caption: examples/tinylora_simpletest_single_channel.py
    :linenos:
